@@ -1,14 +1,16 @@
 """
 Handles azure SSO authentication via flask-dance
 """
+from functools import wraps
+
 from cachetools import TTLCache, cached
+from flask import redirect, url_for
 from flask_dance.contrib.azure import azure
 from oauthlib.oauth2.rfc6749.errors import TokenExpiredError
 
 from api_reflector.reporting import get_logger
 from settings import settings
 
-
 log = get_logger(__name__)
 
 
@@ -39,3 +41,18 @@ def is_authorized():
 
     # otherwise we must have a token and that token must not have expired.
     return azure.authorized and validate_token(azure.access_token)
+
+
+def requires_auth(view_function):
+    """
+    Flask view function decorator that ensures that the user is authenticated.
+    The user is redirected to the Azure login flow if they are not already authenticated.
+    """
+
+    @wraps(view_function)
+    def decorator(*args, **kwargs):
+        if not is_authorized():
+            return redirect(url_for("azure.login"))
+        return view_function(*args, **kwargs)
+
+    return decorator
