@@ -15,6 +15,7 @@ from sqlalchemy import (
     Integer,
     String,
     Table,
+    Text,
     UniqueConstraint,
 )
 from sqlalchemy.orm import DeclarativeMeta, relationship
@@ -73,7 +74,7 @@ class Response(Model):
 
     status_code = Column(Integer, nullable=False, default=200)
     content_type = Column(String, nullable=False, default="application/json")
-    content = Column(String, nullable=False, default="")
+    content = Column(Text, nullable=False, default="")
 
     is_active = Column(Boolean, nullable=False, default=True)
 
